# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

import hod_pb2 as hod__pb2


class HodDBStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.ExecuteQuery = channel.unary_unary(
        '/proto.HodDB/ExecuteQuery',
        request_serializer=hod__pb2.QueryRequest.SerializeToString,
        response_deserializer=hod__pb2.QueryResponse.FromString,
        )


class HodDBServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def ExecuteQuery(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_HodDBServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'ExecuteQuery': grpc.unary_unary_rpc_method_handler(
          servicer.ExecuteQuery,
          request_deserializer=hod__pb2.QueryRequest.FromString,
          response_serializer=hod__pb2.QueryResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'proto.HodDB', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mdal.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='mdal.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\nmdal.proto\x12\x05proto\x1a\x1cgoogle/api/annotations.proto\"\xcd\x02\n\x10\x44\x61taQueryRequest\x12\x13\n\x0b\x63omposition\x18\x01 \x03(\t\x12=\n\x0b\x61ggregation\x18\x02 \x03(\x0b\x32(.proto.DataQueryRequest.AggregationEntry\x12\x39\n\tvariables\x18\x03 \x03(\x0b\x32&.proto.DataQueryRequest.VariablesEntry\x12\x1f\n\x04time\x18\x04 \x01(\x0b\x32\x11.proto.TimeParams\x1a\x46\n\x10\x41ggregationEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.proto.Aggregation:\x02\x38\x01\x1a\x41\n\x0eVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.proto.Variable:\x02\x38\x01\"J\n\x08Variable\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ndefinition\x18\x02 \x01(\t\x12\r\n\x05uuids\x18\x03 \x03(\t\x12\r\n\x05units\x18\x04 \x01(\t\"I\n\nTimeParams\x12\r\n\x05start\x18\x01 \x01(\t\x12\x0b\n\x03\x65nd\x18\x02 \x01(\t\x12\x0e\n\x06window\x18\x03 \x01(\t\x12\x0f\n\x07\x61ligned\x18\x04 \x01(\x08\",\n\x0b\x41ggregation\x12\x1d\n\x05\x66uncs\x18\x01 \x03(\x0e\x32\x0e.proto.AggFunc\"\x93\x04\n\x11\x44\x61taQueryResponse\x12*\n\x04rows\x18\x01 \x03(\x0b\x32\x1c.proto.DataQueryResponse.Row\x12\x36\n\x07mapping\x18\x02 \x03(\x0b\x32%.proto.DataQueryResponse.MappingEntry\x12-\n\x07\x63ontext\x18\x03 \x03(\x0b\x32\x1c.proto.DataQueryResponse.Row\x12\r\n\x05uuids\x18\x04 \x03(\t\x12\r\n\x05\x61rrow\x18\x05 \x01(\x0c\x12\r\n\x05\x65rror\x18\x06 \x01(\t\x12\r\n\x05times\x18\x07 \x03(\x03\x12\x33\n\x06values\x18\x08 \x03(\x0b\x32#.proto.DataQueryResponse.ValueArray\x1as\n\x03Row\x12\x0c\n\x04uuid\x18\x01 \x01(\x0c\x12\x32\n\x03row\x18\x02 \x03(\x0b\x32%.proto.DataQueryResponse.Row.RowEntry\x1a*\n\x08RowEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x17\n\x06VarMap\x12\r\n\x05uuids\x18\x01 \x03(\x0c\x1a\x1b\n\nValueArray\x12\r\n\x05value\x18\x01 \x03(\x01\x1aO\n\x0cMappingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12.\n\x05value\x18\x02 \x01(\x0b\x32\x1f.proto.DataQueryResponse.VarMap:\x02\x38\x01*B\n\x07\x41ggFunc\x12\x07\n\x03RAW\x10\x00\x12\x08\n\x04MEAN\x10\x01\x12\x07\n\x03MIN\x10\x02\x12\x07\n\x03MAX\x10\x03\x12\t\n\x05\x43OUNT\x10\x04\x12\x07\n\x03SUM\x10\x05\x32\x61\n\x04MDAL\x12Y\n\tDataQuery\x12\x17.proto.DataQueryRequest\x1a\x18.proto.DataQueryResponse\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/v1/mdal/query:\x01*b\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])

_AGGFUNC = _descriptor.EnumDescriptor(
  name='AggFunc',
  full_name='proto.AggFunc',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RAW', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MEAN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MIN', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MAX', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COUNT', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUM', index=5, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1118,
  serialized_end=1184,
)
_sym_db.RegisterEnumDescriptor(_AGGFUNC)

AggFunc = enum_type_wrapper.EnumTypeWrapper(_AGGFUNC)
RAW = 0
MEAN = 1
MIN = 2
MAX = 3
COUNT = 4
SUM = 5



_DATAQUERYREQUEST_AGGREGATIONENTRY = _descriptor.Descriptor(
  name='AggregationEntry',
  full_name='proto.DataQueryRequest.AggregationEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='proto.DataQueryRequest.AggregationEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='proto.DataQueryRequest.AggregationEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=248,
  serialized_end=318,
)

_DATAQUERYREQUEST_VARIABLESENTRY = _descriptor.Descriptor(
  name='VariablesEntry',
  full_name='proto.DataQueryRequest.VariablesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='proto.DataQueryRequest.VariablesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='proto.DataQueryRequest.VariablesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=320,
  serialized_end=385,
)

_DATAQUERYREQUEST = _descriptor.Descriptor(
  name='DataQueryRequest',
  full_name='proto.DataQueryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='composition', full_name='proto.DataQueryRequest.composition', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aggregation', full_name='proto.DataQueryRequest.aggregation', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='variables', full_name='proto.DataQueryRequest.variables', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time', full_name='proto.DataQueryRequest.time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DATAQUERYREQUEST_AGGREGATIONENTRY, _DATAQUERYREQUEST_VARIABLESENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=52,
  serialized_end=385,
)


_VARIABLE = _descriptor.Descriptor(
  name='Variable',
  full_name='proto.Variable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='proto.Variable.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='definition', full_name='proto.Variable.definition', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uuids', full_name='proto.Variable.uuids', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='units', full_name='proto.Variable.units', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=387,
  serialized_end=461,
)


_TIMEPARAMS = _descriptor.Descriptor(
  name='TimeParams',
  full_name='proto.TimeParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='proto.TimeParams.start', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end', full_name='proto.TimeParams.end', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='window', full_name='proto.TimeParams.window', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aligned', full_name='proto.TimeParams.aligned', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=463,
  serialized_end=536,
)


_AGGREGATION = _descriptor.Descriptor(
  name='Aggregation',
  full_name='proto.Aggregation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='funcs', full_name='proto.Aggregation.funcs', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=538,
  serialized_end=582,
)


_DATAQUERYRESPONSE_ROW_ROWENTRY = _descriptor.Descriptor(
  name='RowEntry',
  full_name='proto.DataQueryResponse.Row.RowEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='proto.DataQueryResponse.Row.RowEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='proto.DataQueryResponse.Row.RowEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=939,
  serialized_end=981,
)

_DATAQUERYRESPONSE_ROW = _descriptor.Descriptor(
  name='Row',
  full_name='proto.DataQueryResponse.Row',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='proto.DataQueryResponse.Row.uuid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row', full_name='proto.DataQueryResponse.Row.row', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DATAQUERYRESPONSE_ROW_ROWENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=866,
  serialized_end=981,
)

_DATAQUERYRESPONSE_VARMAP = _descriptor.Descriptor(
  name='VarMap',
  full_name='proto.DataQueryResponse.VarMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuids', full_name='proto.DataQueryResponse.VarMap.uuids', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=983,
  serialized_end=1006,
)

_DATAQUERYRESPONSE_VALUEARRAY = _descriptor.Descriptor(
  name='ValueArray',
  full_name='proto.DataQueryResponse.ValueArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='proto.DataQueryResponse.ValueArray.value', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1008,
  serialized_end=1035,
)

_DATAQUERYRESPONSE_MAPPINGENTRY = _descriptor.Descriptor(
  name='MappingEntry',
  full_name='proto.DataQueryResponse.MappingEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='proto.DataQueryResponse.MappingEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='proto.DataQueryResponse.MappingEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1037,
  serialized_end=1116,
)

_DATAQUERYRESPONSE = _descriptor.Descriptor(
  name='DataQueryResponse',
  full_name='proto.DataQueryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rows', full_name='proto.DataQueryResponse.rows', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mapping', full_name='proto.DataQueryResponse.mapping', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='context', full_name='proto.DataQueryResponse.context', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uuids', full_name='proto.DataQueryResponse.uuids', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arrow', full_name='proto.DataQueryResponse.arrow', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='proto.DataQueryResponse.error', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='times', full_name='proto.DataQueryResponse.times', index=6,
      number=7, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values', full_name='proto.DataQueryResponse.values', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DATAQUERYRESPONSE_ROW, _DATAQUERYRESPONSE_VARMAP, _DATAQUERYRESPONSE_VALUEARRAY, _DATAQUERYRESPONSE_MAPPINGENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=585,
  serialized_end=1116,
)

_DATAQUERYREQUEST_AGGREGATIONENTRY.fields_by_name['value'].message_type = _AGGREGATION
_DATAQUERYREQUEST_AGGREGATIONENTRY.containing_type = _DATAQUERYREQUEST
_DATAQUERYREQUEST_VARIABLESENTRY.fields_by_name['value'].message_type = _VARIABLE
_DATAQUERYREQUEST_VARIABLESENTRY.containing_type = _DATAQUERYREQUEST
_DATAQUERYREQUEST.fields_by_name['aggregation'].message_type = _DATAQUERYREQUEST_AGGREGATIONENTRY
_DATAQUERYREQUEST.fields_by_name['variables'].message_type = _DATAQUERYREQUEST_VARIABLESENTRY
_DATAQUERYREQUEST.fields_by_name['time'].message_type = _TIMEPARAMS
_AGGREGATION.fields_by_name['funcs'].enum_type = _AGGFUNC
_DATAQUERYRESPONSE_ROW_ROWENTRY.containing_type = _DATAQUERYRESPONSE_ROW
_DATAQUERYRESPONSE_ROW.fields_by_name['row'].message_type = _DATAQUERYRESPONSE_ROW_ROWENTRY
_DATAQUERYRESPONSE_ROW.containing_type = _DATAQUERYRESPONSE
_DATAQUERYRESPONSE_VARMAP.containing_type = _DATAQUERYRESPONSE
_DATAQUERYRESPONSE_VALUEARRAY.containing_type = _DATAQUERYRESPONSE
_DATAQUERYRESPONSE_MAPPINGENTRY.fields_by_name['value'].message_type = _DATAQUERYRESPONSE_VARMAP
_DATAQUERYRESPONSE_MAPPINGENTRY.containing_type = _DATAQUERYRESPONSE
_DATAQUERYRESPONSE.fields_by_name['rows'].message_type = _DATAQUERYRESPONSE_ROW
_DATAQUERYRESPONSE.fields_by_name['mapping'].message_type = _DATAQUERYRESPONSE_MAPPINGENTRY
_DATAQUERYRESPONSE.fields_by_name['context'].message_type = _DATAQUERYRESPONSE_ROW
_DATAQUERYRESPONSE.fields_by_name['values'].message_type = _DATAQUERYRESPONSE_VALUEARRAY
DESCRIPTOR.message_types_by_name['DataQueryRequest'] = _DATAQUERYREQUEST
DESCRIPTOR.message_types_by_name['Variable'] = _VARIABLE
DESCRIPTOR.message_types_by_name['TimeParams'] = _TIMEPARAMS
DESCRIPTOR.message_types_by_name['Aggregation'] = _AGGREGATION
DESCRIPTOR.message_types_by_name['DataQueryResponse'] = _DATAQUERYRESPONSE
DESCRIPTOR.enum_types_by_name['AggFunc'] = _AGGFUNC
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DataQueryRequest = _reflection.GeneratedProtocolMessageType('DataQueryRequest', (_message.Message,), dict(

  AggregationEntry = _reflection.GeneratedProtocolMessageType('AggregationEntry', (_message.Message,), dict(
    DESCRIPTOR = _DATAQUERYREQUEST_AGGREGATIONENTRY,
    __module__ = 'mdal_pb2'
    # @@protoc_insertion_point(class_scope:proto.DataQueryRequest.AggregationEntry)
    ))
  ,

  VariablesEntry = _reflection.GeneratedProtocolMessageType('VariablesEntry', (_message.Message,), dict(
    DESCRIPTOR = _DATAQUERYREQUEST_VARIABLESENTRY,
    __module__ = 'mdal_pb2'
    # @@protoc_insertion_point(class_scope:proto.DataQueryRequest.VariablesEntry)
    ))
  ,
  DESCRIPTOR = _DATAQUERYREQUEST,
  __module__ = 'mdal_pb2'
  # @@protoc_insertion_point(class_scope:proto.DataQueryRequest)
  ))
_sym_db.RegisterMessage(DataQueryRequest)
_sym_db.RegisterMessage(DataQueryRequest.AggregationEntry)
_sym_db.RegisterMessage(DataQueryRequest.VariablesEntry)

Variable = _reflection.GeneratedProtocolMessageType('Variable', (_message.Message,), dict(
  DESCRIPTOR = _VARIABLE,
  __module__ = 'mdal_pb2'
  # @@protoc_insertion_point(class_scope:proto.Variable)
  ))
_sym_db.RegisterMessage(Variable)

TimeParams = _reflection.GeneratedProtocolMessageType('TimeParams', (_message.Message,), dict(
  DESCRIPTOR = _TIMEPARAMS,
  __module__ = 'mdal_pb2'
  # @@protoc_insertion_point(class_scope:proto.TimeParams)
  ))
_sym_db.RegisterMessage(TimeParams)

Aggregation = _reflection.GeneratedProtocolMessageType('Aggregation', (_message.Message,), dict(
  DESCRIPTOR = _AGGREGATION,
  __module__ = 'mdal_pb2'
  # @@protoc_insertion_point(class_scope:proto.Aggregation)
  ))
_sym_db.RegisterMessage(Aggregation)

DataQueryResponse = _reflection.GeneratedProtocolMessageType('DataQueryResponse', (_message.Message,), dict(

  Row = _reflection.GeneratedProtocolMessageType('Row', (_message.Message,), dict(

    RowEntry = _reflection.GeneratedProtocolMessageType('RowEntry', (_message.Message,), dict(
      DESCRIPTOR = _DATAQUERYRESPONSE_ROW_ROWENTRY,
      __module__ = 'mdal_pb2'
      # @@protoc_insertion_point(class_scope:proto.DataQueryResponse.Row.RowEntry)
      ))
    ,
    DESCRIPTOR = _DATAQUERYRESPONSE_ROW,
    __module__ = 'mdal_pb2'
    # @@protoc_insertion_point(class_scope:proto.DataQueryResponse.Row)
    ))
  ,

  VarMap = _reflection.GeneratedProtocolMessageType('VarMap', (_message.Message,), dict(
    DESCRIPTOR = _DATAQUERYRESPONSE_VARMAP,
    __module__ = 'mdal_pb2'
    # @@protoc_insertion_point(class_scope:proto.DataQueryResponse.VarMap)
    ))
  ,

  ValueArray = _reflection.GeneratedProtocolMessageType('ValueArray', (_message.Message,), dict(
    DESCRIPTOR = _DATAQUERYRESPONSE_VALUEARRAY,
    __module__ = 'mdal_pb2'
    # @@protoc_insertion_point(class_scope:proto.DataQueryResponse.ValueArray)
    ))
  ,

  MappingEntry = _reflection.GeneratedProtocolMessageType('MappingEntry', (_message.Message,), dict(
    DESCRIPTOR = _DATAQUERYRESPONSE_MAPPINGENTRY,
    __module__ = 'mdal_pb2'
    # @@protoc_insertion_point(class_scope:proto.DataQueryResponse.MappingEntry)
    ))
  ,
  DESCRIPTOR = _DATAQUERYRESPONSE,
  __module__ = 'mdal_pb2'
  # @@protoc_insertion_point(class_scope:proto.DataQueryResponse)
  ))
_sym_db.RegisterMessage(DataQueryResponse)
_sym_db.RegisterMessage(DataQueryResponse.Row)
_sym_db.RegisterMessage(DataQueryResponse.Row.RowEntry)
_sym_db.RegisterMessage(DataQueryResponse.VarMap)
_sym_db.RegisterMessage(DataQueryResponse.ValueArray)
_sym_db.RegisterMessage(DataQueryResponse.MappingEntry)


_DATAQUERYREQUEST_AGGREGATIONENTRY.has_options = True
_DATAQUERYREQUEST_AGGREGATIONENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_DATAQUERYREQUEST_VARIABLESENTRY.has_options = True
_DATAQUERYREQUEST_VARIABLESENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_DATAQUERYRESPONSE_ROW_ROWENTRY.has_options = True
_DATAQUERYRESPONSE_ROW_ROWENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_DATAQUERYRESPONSE_MAPPINGENTRY.has_options = True
_DATAQUERYRESPONSE_MAPPINGENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))

_MDAL = _descriptor.ServiceDescriptor(
  name='MDAL',
  full_name='proto.MDAL',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=1186,
  serialized_end=1283,
  methods=[
  _descriptor.MethodDescriptor(
    name='DataQuery',
    full_name='proto.MDAL.DataQuery',
    index=0,
    containing_service=None,
    input_type=_DATAQUERYREQUEST,
    output_type=_DATAQUERYRESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\023\"\016/v1/mdal/query:\001*')),
  ),
])
_sym_db.RegisterServiceDescriptor(_MDAL)

DESCRIPTOR.services_by_name['MDAL'] = _MDAL

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hod.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='hod.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\thod.proto\x12\x05proto\x1a\x1cgoogle/api/annotations.proto\"\x1d\n\x0cQueryRequest\x12\r\n\x05query\x18\x01 \x01(\t\"k\n\rQueryResponse\x12\x10\n\x08variable\x18\x01 \x03(\t\x12\x18\n\x04rows\x18\x02 \x03(\x0b\x32\n.proto.Row\x12\r\n\x05\x63ount\x18\x03 \x01(\x03\x12\x0f\n\x07\x65lapsed\x18\x04 \x01(\x03\x12\x0e\n\x06\x65rrors\x18\x05 \x03(\t\"\x1f\n\x03Row\x12\x18\n\x04uris\x18\x01 \x03(\x0b\x32\n.proto.URI\"\'\n\x03URI\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t2\\\n\x05HodDB\x12S\n\x0c\x45xecuteQuery\x12\x13.proto.QueryRequest\x1a\x14.proto.QueryResponse\"\x18\x82\xd3\xe4\x93\x02\x12\"\r/v1/hod/query:\x01*b\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_QUERYREQUEST = _descriptor.Descriptor(
  name='QueryRequest',
  full_name='proto.QueryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='proto.QueryRequest.query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=50,
  serialized_end=79,
)


_QUERYRESPONSE = _descriptor.Descriptor(
  name='QueryResponse',
  full_name='proto.QueryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='variable', full_name='proto.QueryResponse.variable', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rows', full_name='proto.QueryResponse.rows', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='proto.QueryResponse.count', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='elapsed', full_name='proto.QueryResponse.elapsed', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errors', full_name='proto.QueryResponse.errors', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=81,
  serialized_end=188,
)


_ROW = _descriptor.Descriptor(
  name='Row',
  full_name='proto.Row',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uris', full_name='proto.Row.uris', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=190,
  serialized_end=221,
)


_URI = _descriptor.Descriptor(
  name='URI',
  full_name='proto.URI',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='proto.URI.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='proto.URI.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=223,
  serialized_end=262,
)

_QUERYRESPONSE.fields_by_name['rows'].message_type = _ROW
_ROW.fields_by_name['uris'].message_type = _URI
DESCRIPTOR.message_types_by_name['QueryRequest'] = _QUERYREQUEST
DESCRIPTOR.message_types_by_name['QueryResponse'] = _QUERYRESPONSE
DESCRIPTOR.message_types_by_name['Row'] = _ROW
DESCRIPTOR.message_types_by_name['URI'] = _URI
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

QueryRequest = _reflection.GeneratedProtocolMessageType('QueryRequest', (_message.Message,), dict(
  DESCRIPTOR = _QUERYREQUEST,
  __module__ = 'hod_pb2'
  # @@protoc_insertion_point(class_scope:proto.QueryRequest)
  ))
_sym_db.RegisterMessage(QueryRequest)

QueryResponse = _reflection.GeneratedProtocolMessageType('QueryResponse', (_message.Message,), dict(
  DESCRIPTOR = _QUERYRESPONSE,
  __module__ = 'hod_pb2'
  # @@protoc_insertion_point(class_scope:proto.QueryResponse)
  ))
_sym_db.RegisterMessage(QueryResponse)

Row = _reflection.GeneratedProtocolMessageType('Row', (_message.Message,), dict(
  DESCRIPTOR = _ROW,
  __module__ = 'hod_pb2'
  # @@protoc_insertion_point(class_scope:proto.Row)
  ))
_sym_db.RegisterMessage(Row)

URI = _reflection.GeneratedProtocolMessageType('URI', (_message.Message,), dict(
  DESCRIPTOR = _URI,
  __module__ = 'hod_pb2'
  # @@protoc_insertion_point(class_scope:proto.URI)
  ))
_sym_db.RegisterMessage(URI)



_HODDB = _descriptor.ServiceDescriptor(
  name='HodDB',
  full_name='proto.HodDB',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=264,
  serialized_end=356,
  methods=[
  _descriptor.MethodDescriptor(
    name='ExecuteQuery',
    full_name='proto.HodDB.ExecuteQuery',
    index=0,
    containing_service=None,
    input_type=_QUERYREQUEST,
    output_type=_QUERYRESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\022\"\r/v1/hod/query:\001*')),
  ),
])
_sym_db.RegisterServiceDescriptor(_HODDB)

DESCRIPTOR.services_by_name['HodDB'] = _HODDB

# @@protoc_insertion_point(module_scope)



name = "pymortar"
#from result import Result, deserialize_result
import grpc
import uuid
import pytz
import pandas as pd
import mdal_pb2
import mdal_pb2_grpc
from .client import *

#agg_funcs = {
#    "RAW": mdal_pb2.RAW,
#    "MEAN": mdal_pb2.MEAN,
#    "MIN": mdal_pb2.MIN,
#    "MAX": mdal_pb2.MAX,
#    "COUNT": mdal_pb2.COUNT,
#    "SUM": mdal_pb2.SUM,
#}
#def parse_agg_func(name):
#    return mdal_pb2.AggFunc.Value(name.upper())

#class MDALClient:
#    def __init__(self, caddr):
#        self.channel = grpc.insecure_channel(caddr)
#        self.stub = mdal_pb2_grpc.MDALStub(self.channel)
#
#    def query(self, request):
#        aggs = {}
#        for varname, aggfunclist in request["Aggregation"].items():
#            aggs[varname] = mdal_pb2.Aggregation(funcs=[parse_agg_func(func) for func in aggfunclist])
#        vardefs = {}
#        for varname, defn in request["Variables"].items():
#            vardefs[varname] = mdal_pb2.Variable(
#                name = varname,
#                definition = defn["Definition"],
#                units = defn.get("Units",None),
#            )
#        params = mdal_pb2.DataQueryRequest(
#            composition = request["Composition"],
#            aggregation = aggs,
#            variables = vardefs,
#            time = mdal_pb2.TimeParams(
#                start = request["Time"]["Start"],
#                end = request["Time"]["End"],
#                window = request["Time"]["Window"],
#                aligned = request["Time"]["Aligned"],
#            ),
#        )
#        tz = pytz.timezone("US/Pacific")
#        responses = self.stub.DataQuery(params, timeout=120)
#        for resp in responses:
#            if resp.error != "":
#                raise Exception(resp.error)
#            result = Result(resp)
#            return result
#        #    uuids = [str(uuid.UUID(bytes=x)) for x in resp.uuids]
#        #    data = data_capnp.StreamCollection.from_bytes_packed(resp.arrow)
#        #    if hasattr(data, 'times') and len(data.times):
#        #       times = list(data.times)
#        #       if len(times) == 0:
#        #           return pd.DataFrame(columns=uuids)
#        #       df = pd.DataFrame(index=pd.to_datetime(times, unit='ns', utc=False))
#        #       for idx, s in enumerate(data.streams):
#        #           df[uuids[idx]] = s.values
#        #       df.index = df.index.tz_localize(pytz.utc).tz_convert(tz)
#        #       return df
#        #    else:
#        #       df = pd.DataFrame()
#        #       for idx, s in enumerate(data.streams):
#        #           if hasattr(s, 'times'):
#        #               newdf = pd.DataFrame(list(s.values), index=list(s.times), columns=[uuids[idx]])
#        #               newdf.index = pd.to_datetime(newdf.index, unit='ns').tz_localize(pytz.utc).tz_convert(tz)
#        #               df = df.join(newdf, how='outer')
#        #           else:
#        #               raise Exception("Does this ever happen? Tell gabe!")
#        #       return df
#
#if __name__ == '__main__':
#    m = MDALClient("localhost:8088")
#
#    for windowsize in ["96h","24h","12h","6h","3h","1h","30m","15m","10m","5m","1m","30s"]:
#    #for windowsize in ["1h","30m","15m","10m","5m","1m","30s"]:
#        request = {
#            "Composition": ["temp"],
#            "Aggregation": {
#                "temp": ["MEAN"],
#            },
#            "Variables": {
#                "temp": {
#                    "Definition": """SELECT ?temp ?temp_uuid FROM * WHERE {
#                        ?temp rdf:type/rdfs:subClassOf* brick:Electric_Meter .
#                        ?temp bf:uuid ?temp_uuid
#                    };""",
#                },
#            },
#            "Time": {
#                "Start":  "2017-01-01T10:00:00-07:00",
#                "End":  "2018-05-12T10:00:00-07:00",
#                "Window": windowsize,
#                "Aligned": True,
#            },
#        }
#        try:
#            resp = m.query(request)
#        except Exception as e:
#            print('ERR', e)
#            continue
#
#        print(len(resp.columns), len(resp))
#        print(resp[resp.columns[0]].describe())



import IPython
import grpc
import uuid
#import result
import pytz
import pandas as pd
import hod_pb2
import hod_pb2_grpc
import mdal_pb2
import mdal_pb2_grpc
import mortar_pb2
import mortar_pb2_grpc

agg_funcs = {
    "RAW": mdal_pb2.RAW,
    "MEAN": mdal_pb2.MEAN,
    "MIN": mdal_pb2.MIN,
    "MAX": mdal_pb2.MAX,
    "COUNT": mdal_pb2.COUNT,
    "SUM": mdal_pb2.SUM,
}
def parse_agg_func(name):
    return mdal_pb2.AggFunc.Value(name.upper())

class MortarClient:
    def __init__(self, caddr):
        self.channel = grpc.insecure_channel(caddr, options=[
                  ('grpc.max_send_message_length', 100 * 1024 * 1024),
                  ('grpc.max_receive_message_length', 100 * 1024 * 1024)
        ])
        self.stub = mortar_pb2_grpc.MortarStub(self.channel)

    def qualify(self, required):
        q = [hod_pb2.QueryRequest(query=req) for req in required]
        return self.stub.Qualify(mortar_pb2.QualifyRequest(requiredqueries=q))

    def fetch(self, request):
        aggs = {}
        for varname, aggfunclist in request["Aggregation"].items():
            aggs[varname] = mdal_pb2.Aggregation(funcs=[parse_agg_func(func) for func in aggfunclist])
        #print aggs
        vardefs = {}
        for varname, defn in request["Variables"].items():
            vardefs[varname] = mdal_pb2.Variable(
                name = varname,
                definition = defn["Definition"],
                units = defn.get("Units",None),
            )
        #print vardefs
        params = mdal_pb2.DataQueryRequest(
            composition = request["Composition"],
            aggregation = aggs,
            variables = vardefs,
            time = mdal_pb2.TimeParams(
                start = request["Time"]["Start"],
                end = request["Time"]["End"],
                window = request["Time"]["Window"],
                aligned = request["Time"]["Aligned"],
            ),
        )
        #print params
        tz = pytz.timezone("US/Pacific")
        resp = self.stub.Fetch(mortar_pb2.FetchRequest(request=params), timeout=120)
        if resp.error != "":
            raise Exception(resp.error)
        
        values = [x.value for x in resp.response.values]
        if pd.np.array(values).size > 0:
            print(pd.np.array(values).shape)
            print(pd.np.array(resp.response.times).shape)
            t = resp.response.times
            v = pd.np.array(values)
            if len(resp.response.times) > pd.np.array(values).shape[1]:
                IPython.embed()
            df = pd.DataFrame.from_records(values).T
            df.index = pd.to_datetime(resp.response.times)
            return df
        return None

#class MDALClient:
#    def __init__(self, caddr):
#        self.channel = grpc.insecure_channel(caddr)
#        self.stub = mdal_pb2_grpc.MDALStub(self.channel)
#
#    def query(self, request):
#        aggs = {}
#        for varname, aggfunclist in request["Aggregation"].items():
#            aggs[varname] = mdal_pb2.Aggregation(funcs=[parse_agg_func(func) for func in aggfunclist])
#        #print aggs
#        vardefs = {}
#        for varname, defn in request["Variables"].items():
#            vardefs[varname] = mdal_pb2.Variable(
#                name = varname,
#                definition = defn["Definition"],
#                units = defn.get("Units",None),
#            )
#        #print vardefs
#        params = mdal_pb2.DataQueryRequest(
#            composition = request["Composition"],
#            aggregation = aggs,
#            variables = vardefs,
#            time = mdal_pb2.TimeParams(
#                start = request["Time"]["Start"],
#                end = request["Time"]["End"],
#                window = request["Time"]["Window"],
#                aligned = request["Time"]["Aligned"],
#            ),
#        )
#        #print params
#        tz = pytz.timezone("US/Pacific")
#        resp = self.stub.DataQuery(params, timeout=120)
#        if resp.msg != "":
#            raise Exception(resp.msg)
#        return result.Result(resp)
##        mapping = {}
##        for k, v in resp.mapping.items():
##            mapping[k] = v.uuids
##        context = {}
##        for row in resp.context:
##            context[row.uuid] = dict(row.row)
##        uuids = resp.uuids
##        data = data_capnp.StreamCollection.from_bytes_packed(resp.arrow)
##        if hasattr(data, 'times') and len(data.times):
##            times = list(data.times)
##            if len(times) == 0:
##                return pd.DataFrame(columns=uuids)
##            df = pd.DataFrame(index=pd.to_datetime(times, unit='ns', utc=False))
##            for idx, s in enumerate(data.streams):
##                df[uuids[idx]] = s.values
##            df.index = df.index.tz_localize(pytz.utc).tz_convert(tz)
##            return (df, mapping, context)
##        else:
##            df = pd.DataFrame()
##            for idx, s in enumerate(data.streams):
##                if hasattr(s, 'times'):
##                    newdf = pd.DataFrame(list(s.values), index=list(s.times), columns=[uuids[idx]])
##                    newdf.index = pd.to_datetime(newdf.index, unit='ns').tz_localize(pytz.utc).tz_convert(tz)
##                    df = df.join(newdf, how='outer')
##                else:
##                    raise Exception("Does this ever happen? Tell gabe!")
##            return (df, mapping, context)
#
#if __name__ == '__main__':
#    m = MDALClient("corbusier.cs.berkeley.edu:8088")
#
#    for windowsize in ["96h","24h","12h","6h","3h","1h","30m","15m","10m","5m","1m","30s"]:
#    #for windowsize in ["1h","30m","15m","10m","5m","1m","30s"]:
#        request = {
#            "Composition": ["temp"],
#            "Aggregation": {
#                "temp": ["MEAN"],
#            },
#            "Variables": {
#                "temp": {
#                    "Definition": """SELECT ?temp ?temp_uuid FROM ciee WHERE {
#                        ?temp rdf:type/rdfs:subClassOf* brick:Temperature_Sensor .
#                        ?temp bf:uuid ?temp_uuid
#                    };""",
#                },
#            },
#            "Time": {
#                "Start":  "2017-01-01T10:00:00-07:00",
#                "End":  "2018-05-12T10:00:00-07:00",
#                "Window": windowsize,
#                "Aligned": True,
#            },
#        }
#        resp = m.query(request)
#            
#        print len(resp.columns), len(resp)
#        print resp[resp.columns[0]].describe()

if __name__ == '__main__':
    m = MortarClient("localhost:9001")
    import pickle
    import pathlib
    import os
    cachefilename = "mycache.pickle"
    cachefile = pathlib.Path(cachefilename)
    if cachefile.is_file():
        sites = pickle.load(open(cachefilename, 'rb'))
    else:
        q = """SELECT ?temp ?temp_uuid WHERE {
               ?temp rdf:type/rdfs:subClassOf* brick:Temperature_Sensor .
               ?temp bf:uuid ?temp_uuid
               };""" 
        resp = m.qualify([q])
        sites = list(resp.sites)
        pickle.dump(sites, open(cachefilename, 'wb'))

    for s in sites:
        request = {
            "Composition": ["temp"],
            "Aggregation": {
                "temp": ["MEAN"],
            },
            "Variables": {
                "temp": {
                    "Definition": """SELECT ?temp ?temp_uuid FROM %s WHERE {
                        ?temp rdf:type/rdfs:subClassOf* brick:Temperature_Sensor .
                        ?temp bf:uuid ?temp_uuid
                    };""" % s,
                },
            },
            "Time": {
                "Start":  "2018-08-01T10:00:00-07:00",
                "End":  "2019-01-12T10:00:00-07:00",
                "Window": '1d',
                "Aligned": True,
            },
        }
        resp = m.fetch(request)
        #if len(resp) > 0:
        #    print(resp.describe())



import uuid
import pytz
import pandas as pd
import capnp
import data_capnp
from cached_property import cached_property
from mdal_pb2 import DataQueryResponse

def deserialize_result(s):
    return Result(DataQueryResponse.FromString(s))

class Result(object):
    def __init__(self, response_object, tz = pytz.timezone("US/Pacific")):
        self.tz = tz
        self.serialized = response_object.SerializeToString()
        self.mapping = {}
        self.context = {}
        self.uuids = response_object.uuids
        self.data = data_capnp.StreamCollection.from_bytes_packed(response_object.arrow)
        for row in response_object.context:
            self.context[row.uuid] = dict(row.row)
        for k, v in response_object.mapping.items():
            self.mapping[k] = [str(uuid.UUID(bytes=x)) for x in v.uuids]
        self.df = self._build_df()

    def _build_df(self):
        if hasattr(self.data, 'times') and len(self.data.times):
            times = list(self.data.times)
            if len(times) == 0:
                return pd.DataFrame(columns=self.uuids)
            df = pd.DataFrame(index=pd.to_datetime(times, unit='ns', utc=False))
            for idx, s in enumerate(self.data.streams):
                df[self.uuids[idx]] = s.values
            df.index = df.index.tz_localize(pytz.utc).tz_convert(self.tz)
            return df
        else:
            df = pd.DataFrame()
            for idx, s in enumerate(self.data.streams):
                if hasattr(s, 'times'):
                    newdf = pd.DataFrame(list(s.values), index=list(s.times), columns=[self.uuids[idx]])
                    newdf.index = pd.to_datetime(newdf.index, unit='ns').tz_localize(pytz.utc).tz_convert(self.tz)
                    df = df.join(newdf, how='outer')
                else:
                    raise Exception("Does this ever happen? Tell gabe!")
            return df

    def join_on(self, uuid, key, varnames=None):
        uuids = [uuid]
        joinval = self.context.get(uuid)
        if joinval is None:
            raise KeyError("No value for key {0} on uuid {1}".format(key, uuid))
        if varnames is not None:
            for varname in varnames:
                for uuid in self.mapping[varname]:
                    metadata = self.context[uuid]
                    if metadata.get(key) == joinval[key]:
                        uuids.append(uuid)
        else:
            for uuid, metadata in self.context.items():
                if metadata.get(key) == joinval[key]:
                    uuids.append(uuid)
        return uuids

        

    @cached_property()
    def context(self):
        for row in self.response_object.context:
            self._context[str(uuid.UUID(bytes=row.uuid))] = dict(row.row)
        return self._context

    @cached_property()
    def mapping(self):
        for k, v in self.response_object.mapping.items():
            self._mapping[k] = [str(uuid.UUID(bytes=x)) for x in v.uuids]
        return self._mapping



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mortar.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import hod_pb2 as hod__pb2
import mdal_pb2 as mdal__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='mortar.proto',
  package='proto',
  syntax='proto3',
  serialized_pb=_b('\n\x0cmortar.proto\x12\x05proto\x1a\thod.proto\x1a\nmdal.proto\x1a\x1cgoogle/api/annotations.proto\"l\n\x0eQualifyRequest\x12,\n\x0frequiredqueries\x18\x01 \x03(\x0b\x32\x13.proto.QueryRequest\x12,\n\x0foptionalqueries\x18\x02 \x03(\x0b\x32\x13.proto.QueryRequest\"/\n\x0fQualifyResponse\x12\r\n\x05\x65rror\x18\x01 \x01(\t\x12\r\n\x05sites\x18\x02 \x03(\t\"8\n\x0c\x46\x65tchRequest\x12(\n\x07request\x18\x01 \x01(\x0b\x32\x17.proto.DataQueryRequest\"J\n\rFetchResponse\x12\r\n\x05\x65rror\x18\x01 \x01(\t\x12*\n\x08response\x18\x02 \x01(\x0b\x32\x18.proto.DataQueryResponse2\xb4\x01\n\x06Mortar\x12W\n\x07Qualify\x12\x15.proto.QualifyRequest\x1a\x16.proto.QualifyResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/v1/mortar/qualify:\x01*\x12Q\n\x05\x46\x65tch\x12\x13.proto.FetchRequest\x1a\x14.proto.FetchResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/v1/mortar/qualify:\x01*b\x06proto3')
  ,
  dependencies=[hod__pb2.DESCRIPTOR,mdal__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_QUALIFYREQUEST = _descriptor.Descriptor(
  name='QualifyRequest',
  full_name='proto.QualifyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='requiredqueries', full_name='proto.QualifyRequest.requiredqueries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='optionalqueries', full_name='proto.QualifyRequest.optionalqueries', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=76,
  serialized_end=184,
)


_QUALIFYRESPONSE = _descriptor.Descriptor(
  name='QualifyResponse',
  full_name='proto.QualifyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='proto.QualifyResponse.error', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sites', full_name='proto.QualifyResponse.sites', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=186,
  serialized_end=233,
)


_FETCHREQUEST = _descriptor.Descriptor(
  name='FetchRequest',
  full_name='proto.FetchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='proto.FetchRequest.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=235,
  serialized_end=291,
)


_FETCHRESPONSE = _descriptor.Descriptor(
  name='FetchResponse',
  full_name='proto.FetchResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='proto.FetchResponse.error', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='response', full_name='proto.FetchResponse.response', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=293,
  serialized_end=367,
)

_QUALIFYREQUEST.fields_by_name['requiredqueries'].message_type = hod__pb2._QUERYREQUEST
_QUALIFYREQUEST.fields_by_name['optionalqueries'].message_type = hod__pb2._QUERYREQUEST
_FETCHREQUEST.fields_by_name['request'].message_type = mdal__pb2._DATAQUERYREQUEST
_FETCHRESPONSE.fields_by_name['response'].message_type = mdal__pb2._DATAQUERYRESPONSE
DESCRIPTOR.message_types_by_name['QualifyRequest'] = _QUALIFYREQUEST
DESCRIPTOR.message_types_by_name['QualifyResponse'] = _QUALIFYRESPONSE
DESCRIPTOR.message_types_by_name['FetchRequest'] = _FETCHREQUEST
DESCRIPTOR.message_types_by_name['FetchResponse'] = _FETCHRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

QualifyRequest = _reflection.GeneratedProtocolMessageType('QualifyRequest', (_message.Message,), dict(
  DESCRIPTOR = _QUALIFYREQUEST,
  __module__ = 'mortar_pb2'
  # @@protoc_insertion_point(class_scope:proto.QualifyRequest)
  ))
_sym_db.RegisterMessage(QualifyRequest)

QualifyResponse = _reflection.GeneratedProtocolMessageType('QualifyResponse', (_message.Message,), dict(
  DESCRIPTOR = _QUALIFYRESPONSE,
  __module__ = 'mortar_pb2'
  # @@protoc_insertion_point(class_scope:proto.QualifyResponse)
  ))
_sym_db.RegisterMessage(QualifyResponse)

FetchRequest = _reflection.GeneratedProtocolMessageType('FetchRequest', (_message.Message,), dict(
  DESCRIPTOR = _FETCHREQUEST,
  __module__ = 'mortar_pb2'
  # @@protoc_insertion_point(class_scope:proto.FetchRequest)
  ))
_sym_db.RegisterMessage(FetchRequest)

FetchResponse = _reflection.GeneratedProtocolMessageType('FetchResponse', (_message.Message,), dict(
  DESCRIPTOR = _FETCHRESPONSE,
  __module__ = 'mortar_pb2'
  # @@protoc_insertion_point(class_scope:proto.FetchResponse)
  ))
_sym_db.RegisterMessage(FetchResponse)



_MORTAR = _descriptor.ServiceDescriptor(
  name='Mortar',
  full_name='proto.Mortar',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=370,
  serialized_end=550,
  methods=[
  _descriptor.MethodDescriptor(
    name='Qualify',
    full_name='proto.Mortar.Qualify',
    index=0,
    containing_service=None,
    input_type=_QUALIFYREQUEST,
    output_type=_QUALIFYRESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\027\"\022/v1/mortar/qualify:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='Fetch',
    full_name='proto.Mortar.Fetch',
    index=1,
    containing_service=None,
    input_type=_FETCHREQUEST,
    output_type=_FETCHRESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\027\"\022/v1/mortar/qualify:\001*')),
  ),
])
_sym_db.RegisterServiceDescriptor(_MORTAR)

DESCRIPTOR.services_by_name['Mortar'] = _MORTAR

# @@protoc_insertion_point(module_scope)



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="pymortar",
    version="0.0.3",
    author="Gabe Fierro",
    author_email="gtfierro@cs.berkeley.edu",
    description="Python3 Mortar",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/mortar-frontend",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
    ],
)
